import javax.xml.bind.JAXBContext;
import javax.xml.bind.Marshaller;

import iso.std.iso._20022.tech.xsd.pain_001_001.*;

import java.io.File;
import java.io.StringWriter;
import java.io.PrintStream;

import javax.xml.bind.Unmarshaller;
import java.io.StringReader;

import javax.xml.XMLConstants;
import javax.xml.validation.Schema;
import javax.xml.validation.SchemaFactory;
import javax.xml.validation.Validator;

import javax.xml.transform.stream.StreamSource;

import java.nio.charset.Charset;
import java.nio.file.Files;
import java.nio.file.Paths;
import java.util.stream.Collectors;

import java.io.BufferedReader;
import java.util.Base64;

import javax.xml.datatype.XMLGregorianCalendar;
import javax.xml.datatype.DatatypeFactory;
import javax.xml.datatype.DatatypeConstants;

import java.text.DateFormat;
import java.text.SimpleDateFormat;
import java.util.Date;
import java.util.GregorianCalendar;

import java.math.BigDecimal;

public class Pain001w {
    public static void main(String[] args) {

        // XMLドキュメントルート
        Document doc = new Document();

        // 総合振込依頼ルート
        CustomerCreditTransferInitiationV03 ccti = new CustomerCreditTransferInitiationV03();
        doc.setCstmrCdtTrfInitn(ccti);

        // グループヘッダー情報
        GroupHeader32 gh1 = new GroupHeader32();
        ccti.setGrpHdr(gh1);

        // グループメッセージID
        gh1.setMsgId("msgid");

        // XMLファイル作成日付
        try {
            XMLGregorianCalendar xmlGregCal1 = DatatypeFactory.newInstance().newXMLGregorianCalendar(new GregorianCalendar());
            gh1.setCreDtTm(xmlGregCal1);
            
            xmlGregCal1.setYear(2018);
            xmlGregCal1.setMonth(3);
            xmlGregCal1.setDay(2);
            xmlGregCal1.setTimezone(9);
            xmlGregCal1.setTime(20, 11, 10);
            
            // System.out.println(xmlGregCal);
        } catch (Exception e) {
            e.printStackTrace();
        }

        // 支払情報数
        gh1.setNbOfTxs("1");

        // 開始集団
        PartyIdentification32 pi1 = new PartyIdentification32();
        gh1.setInitgPty(pi1);

        // 支払情報
        PaymentInstructionInformation3 pii = new PaymentInstructionInformation3();
        ccti.getPmtInf().add(pii);

        // 支払情報ID
        pii.setPmtInfId("pmtinfid1");
        pii.setPmtMtd(PaymentMethod3Code.TRF);

        // 合計件数
        pii.setNbOfTxs("1");
        
        // 合計金額
        pii.setCtrlSum(new BigDecimal("12345"));

        // 支払種別情報
        PaymentTypeInformation19 pti = new PaymentTypeInformation19();
        pii.setPmtTpInf(pti);
        CategoryPurpose1Choice cp1 = new CategoryPurpose1Choice();
        pti.setCtgyPurp(cp1);
        cp1.setCd("OTHR");

        // 取組日
        try {
            DateFormat format1 = new SimpleDateFormat("yyyy-MM-dd");
            Date date1 = format1.parse("2018-03-02");
            GregorianCalendar cal1 = new GregorianCalendar();
            cal1.setTime(date1);
            XMLGregorianCalendar xmlGregCal2 = DatatypeFactory.newInstance().newXMLGregorianCalendar(cal1);
            xmlGregCal2.setTimezone(DatatypeConstants.FIELD_UNDEFINED);
            pii.setReqdExctnDt(xmlGregCal2);
            // System.out.println(xmlGregCal);
        } catch (Exception e) {
            e.printStackTrace();
        }

        // 振込依頼人情報
        PartyIdentification32 pi2 = new PartyIdentification32();
        pii.setDbtr(pi2);
        Party6Choice p1 = new Party6Choice();
        pi2.setId(p1);
        OrganisationIdentification4 oid1 = new OrganisationIdentification4();
        p1.setOrgId(oid1);

        // 振込依頼人コード
        GenericOrganisationIdentification1 goid1 = new GenericOrganisationIdentification1();
        oid1.getOthr().add(goid1);
        goid1.setId("1234567890");
        OrganisationIdentificationSchemeName1Choice oidshnm1 = new OrganisationIdentificationSchemeName1Choice();
        goid1.setSchmeNm(oidshnm1);
        oidshnm1.setCd("BANK");

        // 振込依頼人法人番号（法人マイナンバー）情報
        GenericOrganisationIdentification1 goid2 = new GenericOrganisationIdentification1();
        oid1.getOthr().add(goid2);
        goid2.setId("1234567890123");
        OrganisationIdentificationSchemeName1Choice oidshnm2 = new OrganisationIdentificationSchemeName1Choice();
        goid2.setSchmeNm(oidshnm2);
        oidshnm2.setCd("TXID");

        // 振込依頼人口座情報
        CashAccount16 ca1 = new CashAccount16();
        pii.setDbtrAcct(ca1);
        AccountIdentification4Choice ai1 = new AccountIdentification4Choice();
        ca1.setId(ai1);

        // 振込依頼人口座番号
        GenericAccountIdentification1 gai1 = new GenericAccountIdentification1();
        gai1.setId("0010000001");
        ai1.setOthr(gai1);

        // 振込依頼人預金種目
        CashAccountType2 cat1 = new CashAccountType2();
        cat1.setPrtry("1");
        ca1.setTp(cat1);

        // 仕向金融機関情報
        BranchAndFinancialInstitutionIdentification4 bfii1 = new BranchAndFinancialInstitutionIdentification4();
        pii.setDbtrAgt(bfii1);
        FinancialInstitutionIdentification7 fii1 = new FinancialInstitutionIdentification7();
        bfii1.setFinInstnId(fii1);
        ClearingSystemMemberIdentification2 csmi1 = new ClearingSystemMemberIdentification2();
        fii1.setClrSysMmbId(csmi1);
        ClearingSystemIdentification2Choice csid1 = new ClearingSystemIdentification2Choice();
        csmi1.setClrSysId(csid1);
        csid1.setCd("JPZGN");

        // 仕向銀行番号
        csmi1.setMmbId("0000");

        // 仕向銀行名
        fii1.setNm("ｼﾑｹｷﾞﾝｺｳﾒｲ");

        BranchData2 bd1 = new BranchData2();
        bfii1.setBrnchId(bd1);

        // 仕向支店番号
        bd1.setId("000");

        // 仕向支店名
        bd1.setNm("ｼﾑｹｼﾃﾝﾒｲ");

        // 振込依頼人名
        PartyIdentification32 upi = new PartyIdentification32();
        pii.setUltmtDbtr(upi);
        upi.setNm("ﾌﾘｺﾐｲﾗｲﾆﾝﾒｲ");

        // 取引明細
        CreditTransferTransactionInformation10 ctti = new CreditTransferTransactionInformation10();
        pii.getCdtTrfTxInf().add(ctti);
        PaymentIdentification1 pid = new PaymentIdentification1();
        ctti.setPmtId(pid);

        // 取引明細識別番号 (振込依頼人発行)
        pid.setEndToEndId("E4AE332F626448268E3852CA76A81620");

        // 振込金額情報
        AmountType3Choice amt = new AmountType3Choice();
        ctti.setAmt(amt);
        ActiveOrHistoricCurrencyAndAmount aamt = new ActiveOrHistoricCurrencyAndAmount();
        amt.setInstdAmt(aamt);

        // 振込金額
        aamt.setValue(new BigDecimal(12345));
        aamt.setCcy("JPY");

        // 被仕向銀行情報
        BranchAndFinancialInstitutionIdentification4 bfii2 = new BranchAndFinancialInstitutionIdentification4();
        ctti.setCdtrAgt(bfii2);
        FinancialInstitutionIdentification7 fii2 = new FinancialInstitutionIdentification7();
        bfii2.setFinInstnId(fii2);
        ClearingSystemMemberIdentification2 csmi2 = new ClearingSystemMemberIdentification2();
        fii2.setClrSysMmbId(csmi2);
        ClearingSystemIdentification2Choice csid2 = new ClearingSystemIdentification2Choice();
        csmi2.setClrSysId(csid2);
        csid2.setCd("JPZGN");

        // 被仕向銀行番号
        csmi2.setMmbId("9999");

        // 被仕向銀行名
        fii2.setNm("ﾋｼﾑｹｷﾞﾝｺｳﾒｲ");

        // 手形交換所番号
        GenericFinancialIdentification1 gfi = new GenericFinancialIdentification1();
        fii2.setOthr(gfi);
        gfi.setId("1111");

        // 被仕向支店情報
        BranchData2 bd2 = new BranchData2();
        bfii2.setBrnchId(bd2);

        // 被仕向支店番号
        bd2.setId("999");

        // 被仕向支店名
        bd2.setNm("ﾋｼﾑｹｼﾃﾝﾒｲ");

        // 受取人情報
        PartyIdentification32 pi3 = new PartyIdentification32();
        ctti.setCdtr(pi3);
        Party6Choice p2 = new Party6Choice();
        pi3.setId(p2);
        OrganisationIdentification4 oid2 = new OrganisationIdentification4();
        p2.setOrgId(oid2);

        // 受取人名
        pi3.setNm("ｳｹﾄﾘﾆﾝﾒｲ");

        // 受取人法人番号（法人マイナンバー）情報
        GenericOrganisationIdentification1 goid3 = new GenericOrganisationIdentification1();
        oid2.getOthr().add(goid3);
        goid3.setId("1234567890123");
        OrganisationIdentificationSchemeName1Choice oidshnm3 = new OrganisationIdentificationSchemeName1Choice();
        goid3.setSchmeNm(oidshnm3);
        oidshnm3.setCd("TXID");

        // 顧客コード１情報
        GenericOrganisationIdentification1 goid4 = new GenericOrganisationIdentification1();
        oid2.getOthr().add(goid4);
        goid4.setId("1234567890");
        OrganisationIdentificationSchemeName1Choice oidshnm4 = new OrganisationIdentificationSchemeName1Choice();
        goid4.setSchmeNm(oidshnm4);
        oidshnm4.setPrtry("Customer Code1");

        // 顧客コード２情報
        GenericOrganisationIdentification1 goid5 = new GenericOrganisationIdentification1();
        oid2.getOthr().add(goid5);
        goid5.setId("1234567890");
        OrganisationIdentificationSchemeName1Choice oidshnm5 = new OrganisationIdentificationSchemeName1Choice();
        goid5.setSchmeNm(oidshnm5);
        oidshnm5.setPrtry("Customer Code2");

        // 受取人口座情報
        CashAccount16 ca2 = new CashAccount16();
        ctti.setCdtrAcct(ca2);
        AccountIdentification4Choice ai2 = new AccountIdentification4Choice();
        ca2.setId(ai2);

        // 受取人口座番号
        GenericAccountIdentification1 gai2 = new GenericAccountIdentification1();
        gai2.setId("0010000001");
        ai2.setOthr(gai2);

        // 受取人預金種目
        CashAccountType2 cat2 = new CashAccountType2();
        cat2.setPrtry("1");
        ca2.setTp(cat2);

        // 振込指定区分情報
        InstructionForCreditorAgent1 ifca = new InstructionForCreditorAgent1();
        ctti.getInstrForCdtrAgt().add(ifca);

        // 振込指定区分
        ifca.setInstrInf("7");

        // 識別表示および仕向金融機関指示情報
        ctti.setInstrForDbtrAgt(new InstrForDbtrAgt("Y", "dummy01", "dummy0123456789du").Unparse());

        // 新規コード
        Purpose2Choice purp = new Purpose2Choice();
        ctti.setPurp(purp);
        purp.setPrtry("0");

        // 商流情報
        RemittanceInformation5 ri = new RemittanceInformation5();
        ctti.setRmtInf(ri);

        // XML形式の場合
        // MIMEヘッダー
        ri.getUstrd().add("MIME-Version: 1.0");
        ri.getUstrd().add("Content-Type: text/xml");
        ri.getUstrd().add("Content-Transfer-Encoding: base64");

        // 商流情報ファイル（XML形式）
        String path ="CrossIndustryRemittanceAdvice.xml";

        String crlf = System.getProperty("line.separator");
        try {
            String edi = Files.lines(Paths.get(path), Charset.forName("UTF-8"))
                      .collect(Collectors.joining(crlf));
            String encoded = Base64.getMimeEncoder()
                .encodeToString(edi.getBytes());
            //System.out.println(encoded);
            
            BufferedReader br = new BufferedReader(new StringReader(encoded));
            String s;
            while ((s = br.readLine()) != null) {
                ri.getUstrd().add(s);
                //System.out.println("<Ustrd>" + s + "</Ustrd>");
            }
        } catch (Exception e) {
            e.printStackTrace();
        }

/*
        // 平文形式の場合
        // 商流情報ファイル（平文形式）
        String path ="RemittanceAdvice.txt";
        try {
            BufferedReader br = Files.newBufferedReader(Paths.get(path), Charset.forName("UTF-8"));
            String s;
            while ((s = br.readLine()) != null) {
                ri.getUstrd().add(s);
                //System.out.println("<Ustrd>" + s + "</Ustrd>");
            }

        } catch (Exception e) {
            e.printStackTrace();
        }
*/

        StringWriter stringWriter = new StringWriter();
        try {
            SchemaFactory sf = SchemaFactory.newInstance(XMLConstants.W3C_XML_SCHEMA_NS_URI); 
            Schema schema = sf.newSchema(new File("pain.001.001.03.xsd"));
    
            JAXBContext context = JAXBContext.newInstance(Document.class);
            Marshaller marshaller = context.createMarshaller();
            marshaller.setSchema(schema);
            marshaller.setEventHandler(new MyValidationEventHandler());

            // インデントした形式とする場合
            marshaller.setProperty(Marshaller.JAXB_FORMATTED_OUTPUT, true);
            // XMLヘッダーを生成しない場合
            //marshaller.setProperty(Marshaller.JAXB_FRAGMENT, true); 
            // 出力対象によりXMLヘッダーの扱いが変わることに注意
            //stringWriter.write("<?xml version=\"1.0\" encoding=\"UTF-8\" standalone=\"no\"?>");

            marshaller.marshal(doc, stringWriter);

            // 標準出力に出す場合
            PrintStream out = new PrintStream(System.out, true, "UTF-8");
            // BOMを付ける場合
            // out.write(0xef);
            // out.write(0xbb);
            // out.write(0xbf);
            out.print(stringWriter.toString());
        } catch (Exception e) {
            e.printStackTrace();
        }
    }
}