import java.io.File;
import java.io.BufferedReader;
import java.io.PrintStream;

import java.nio.file.Paths;
import java.nio.file.Files;
import java.nio.charset.Charset;

import javax.xml.XMLConstants;
import javax.xml.validation.Schema;
import javax.xml.validation.SchemaFactory;

import javax.xml.stream.XMLInputFactory;
import javax.xml.stream.XMLEventReader;
import javax.xml.stream.events.XMLEvent;

import javax.xml.bind.JAXBContext;
import javax.xml.bind.Unmarshaller;
import un.unece.uncefact.data.standard.crossindustryremittanceadvice._11.*;

public class RAIN {
    public static void main(String[] args) {

        try {
            PrintStream out = new PrintStream(System.out, true, "UTF-8");

            // 商流情報ファイル
            String path ="CrossIndustryRemittanceAdvice.xml";

            BufferedReader br = Files.newBufferedReader(Paths.get(path), 
                                        Charset.forName("UTF-8"));
            if(br.markSupported()) {
                // out.println("mark supported");
                br.mark(1024);
            }

            String ns = "";
            XMLInputFactory factory = XMLInputFactory.newInstance();
            XMLEventReader r = factory.createXMLEventReader(br);

            while(r.hasNext()) {
                XMLEvent e = r.nextEvent();
                if(e.isStartElement()) {
                    ns = e.asStartElement().getName().getNamespaceURI();
                    out.println("namespace["+ ns +"]");
                    break;
                }
            }

            if(ns == "urn:un:unece:uncefact:data:standard:CrossIndustryRemittanceAdvice:11") {

                // Cross Industry Remittance Adviceの処理
                if(br.markSupported()) {
                    // out.println("mark reset");
                    br.reset();
                } else {
                    br = Files.newBufferedReader(Paths.get(path), 
                                    Charset.forName("UTF-8"));
                }

                SchemaFactory sFactory = SchemaFactory
                    .newInstance(XMLConstants.W3C_XML_SCHEMA_NS_URI); 
                Schema schema = sFactory.newSchema(
                    new File("CrossIndustryRemittanceAdvice.xsd")); 

                Unmarshaller unmarshaller = JAXBContext.newInstance(
                    CrossIndustryRemittanceAdvice.class).createUnmarshaller();
                unmarshaller.setSchema(schema);

                CrossIndustryRemittanceAdvice cira = 
                    (CrossIndustryRemittanceAdvice) unmarshaller.unmarshal(br);

                // データ区分
                out.println("CIExchangedDocumentContext/" 
                    + "BusinessProcessSpecifiedCIDocumentContextParameter/");
                try {
                    out.println("ID[" + cira.getCIExchangedDocumentContext()
                        .getBusinessProcessSpecifiedCIDocumentContextParameter()
                        .getID().getValue() + "]");
                } catch (NullPointerException e) {
                    out.println("[No ID]");
                }

                // 業界区分
                out.println("CIExchangedDocumentContext/" 
                    + "SubsetSpecifiedCIDocumentContextParameter/");
                try {
                    out.println("ID[" + cira.getCIExchangedDocumentContext()
                        .getSubsetSpecifiedCIDocumentContextParameter()
                        .getID().getValue() + "]");
                } catch (NullPointerException e) {
                    out.println("[No ID]");
                }

                // 支払通知番号
                out.println("CIRExchangedDocument/");
                try {
                    out.println("ID[" + cira.getCIRExchangedDocument()
                        .getID().getValue() + "]");
                } catch (NullPointerException e) {
                    out.println("[No ID]");
                }

                // 支払通知発行日
                out.println("CIRExchangedDocument/");
                try {
                    out.println("IssueDateTime/DateTime[" + cira
                        .getCIRExchangedDocument().getIssueDateTime()
                        .getDateTime() + "]");
                } catch (NullPointerException e) {
                    out.println("[No IssueDateTime/DateTime]");
                }

                // 支払内容
                out.println("CIRExchangedDocument/IncludedCINote[0]/");
                try {
                    out.println("Content[" + cira.getCIRExchangedDocument()
                        .getIncludedCINote().get(0).getContent().getValue() + "]");
                } catch (NullPointerException e) {
                    out.println("[No Content]");
                } catch(IndexOutOfBoundsException e) {
                    out.println("[No IncludedCINote]");
                }

                // 支払番号
                out.println("CIRHTradeSettlementPayment/");
                try {
                    out.println("EndToEndID[" + cira
                        .getCIRHTradeSettlementPayment().getEndToEndID()
                        .getValue() + "]");
                } catch (NullPointerException e) {
                    out.println("[No EndToEndID]");
                }

                // 支払日時
                out.println("CIRHTradeSettlementPayment/");
                try {
                    out.println("RequestedExecutionDateTime/DateTime[" 
                        + cira.getCIRHTradeSettlementPayment()
                        .getRequestedExecutionDateTime().getDateTime() + "]");
                } catch (NullPointerException e) {
                    out.println("[No RequestedExecutionDateTime/DateTime]");
                }

                // 受取人企業法人コード
                out.println("CIRHTradeSettlementPayment" 
                    + "/SpecifiedCIRHSupplyChainTradeSettlement[0]"
                    + "/PayeeCITradeParty/");
                try {
                    out.println("GlobalID[" + cira.getCIRHTradeSettlementPayment()
                        .getSpecifiedCIRHSupplyChainTradeSettlement().get(0)
                        .getPayeeCITradeParty().getGlobalID().getValue() + "]");
                } catch (NullPointerException e) {
                    out.println("[No GlobalID]");
                } catch(IndexOutOfBoundsException e) {
                    out.println("[No SpecifiedCIRHSupplyChainTradeSettlement]");
                }

                // 受取人企業名
                out.println("CIRHTradeSettlementPayment" 
                    + "/SpecifiedCIRHSupplyChainTradeSettlement[0]" 
                    + "/PayeeCITradeParty/");
                try {
                    out.println("Name[" + cira.getCIRHTradeSettlementPayment()
                        .getSpecifiedCIRHSupplyChainTradeSettlement().get(0)
                        .getPayeeCITradeParty().getName().getValue() + "]");
                } catch (NullPointerException e) {
                    out.println("[No Name]");
                } catch(IndexOutOfBoundsException e) {
                    out.println("[No SpecifiedCIRHSupplyChainTradeSettlement]");
                }

                // 受取企業連絡先電話番号
                out.println("CIRHTradeSettlementPayment" 
                    + "/SpecifiedCIRHSupplyChainTradeSettlement[0]" 
                    + "/PayeeCITradeParty/DefinedCITradeContact"
                    + "/TelephoneCIUniversalCommunication/");
                try {
                    out.println("CompleteNumber[" 
                        + cira.getCIRHTradeSettlementPayment()
                        .getSpecifiedCIRHSupplyChainTradeSettlement().get(0)
                        .getPayeeCITradeParty().getDefinedCITradeContact()
                        .getTelephoneCIUniversalCommunication()
                        .getCompleteNumber().getValue() + "]");
                } catch (NullPointerException e) {
                    out.println("[No CompleteNumber]");
                } catch(IndexOutOfBoundsException e) {
                    out.println("[No SpecifiedCIRHSupplyChainTradeSettlement]");
                }

                // 支払人企業法人コード
                out.println("CIRHTradeSettlementPayment/" 
                    + "SpecifiedCIRHSupplyChainTradeSettlement[0]" 
                    + "/PayerCITradeParty/");
                try {
                    out.println("GlobalID[" + cira.getCIRHTradeSettlementPayment()
                        .getSpecifiedCIRHSupplyChainTradeSettlement().get(0)
                        .getPayerCITradeParty().getGlobalID().getValue() + "]");
                } catch (NullPointerException e) {
                    out.println("[No GlobalID]");
                } catch(IndexOutOfBoundsException e) {
                    out.println("[No SpecifiedCIRHSupplyChainTradeSettlement]");
                }

                // 支払人企業名
                out.println("CIRHTradeSettlementPayment/" 
                    + "SpecifiedCIRHSupplyChainTradeSettlement[0]" 
                    + "/PayerCITradeParty/");
                try {
                    out.println("Name[" + cira.getCIRHTradeSettlementPayment()
                        .getSpecifiedCIRHSupplyChainTradeSettlement().get(0)
                        .getPayerCITradeParty().getName().getValue() + "]");
                } catch (NullPointerException e) {
                    out.println("[No Name]");
                } catch(IndexOutOfBoundsException e) {
                    out.println("[No SpecifiedCIRHSupplyChainTradeSettlement]");
                }

                // 支払企業連絡先電話番号
                out.println("CIRHTradeSettlementPayment" 
                    + "/SpecifiedCIRHSupplyChainTradeSettlement[0]"
                    + "/PayerCITradeParty/DefinedCITradeContact" 
                    + "/TelephoneCIUniversalCommunication/");
                try {
                    out.println("CompleteNumber[" 
                        + cira.getCIRHTradeSettlementPayment()
                        .getSpecifiedCIRHSupplyChainTradeSettlement().get(0)
                        .getPayerCITradeParty().getDefinedCITradeContact()
                        .getTelephoneCIUniversalCommunication()
                        .getCompleteNumber().getValue() + "]");
                } catch (NullPointerException e) {
                    out.println("[No CompleteNumber]");
                } catch(IndexOutOfBoundsException e) {
                    out.println("[No SpecifiedCIRHSupplyChainTradeSettlement]");
                }

                // 支払合計金額
                out.println("CIRHTradeSettlementPayment" 
                    + "/SpecifiedCIRHSupplyChainTradeSettlement[0]"
                    + "/SpecifiedCIRHTradeSettlementMonetarySummation/");
                try {
                    out.println("PaymentTotalAmount[" + cira
                        .getCIRHTradeSettlementPayment()
                        .getSpecifiedCIRHSupplyChainTradeSettlement().get(0)
                        .getSpecifiedCIRHTradeSettlementMonetarySummation()
                        .getPaymentTotalAmount().getValue() + "]");
                } catch (NullPointerException e) {
                    out.println("[No PaymentTotalAmount]");
                } catch(IndexOutOfBoundsException e) {
                    out.println("[No SpecifiedCIRHSupplyChainTradeSettlement]");
                }

                // 金額相殺項目理由コード
                out.println("CIRHTradeSettlementPayment" 
                    + "/SpecifiedCIRHSupplyChainTradeSettlement[0]"
                    + "/SpecifiedCIRHTradeSettlementMonetarySummation" 
                    + "/ApplicableCIRHSpecifiedBalanceOut/");
                try {
                    out.println("ReasonCode[" 
                        + cira.getCIRHTradeSettlementPayment()
                        .getSpecifiedCIRHSupplyChainTradeSettlement().get(0)
                        .getSpecifiedCIRHTradeSettlementMonetarySummation()
                        .getApplicableCIRHSpecifiedBalanceOut().get(0)
                        .getReasonCode().getValue() + "]");
                } catch (NullPointerException e) {
                    out.println("[No ReasonCode]");
                } catch(IndexOutOfBoundsException e) {
                    out.println("[No SpecifiedCIRHSupplyChainTradeSettlement" 
                        + "/ApplicableCIRHSpecifiedBalanceOut]");
                }

                // 金額相殺項目理由
                out.println("CIRHTradeSettlementPayment" 
                    + "/SpecifiedCIRHSupplyChainTradeSettlement[0]"
                    + "/SpecifiedCIRHTradeSettlementMonetarySummation" 
                    + "/ApplicableCIRHSpecifiedBalanceOut/");
                try {
                    out.println("ReasonDescription[" + cira
                        .getCIRHTradeSettlementPayment()
                        .getSpecifiedCIRHSupplyChainTradeSettlement().get(0)
                        .getSpecifiedCIRHTradeSettlementMonetarySummation()
                        .getApplicableCIRHSpecifiedBalanceOut().get(0)
                        .getReasonDescription().getValue() + "]");
                } catch (NullPointerException e) {
                    out.println("[No ReasonDescription]");
                } catch(IndexOutOfBoundsException e) {
                    out.println("[No SpecifiedCIRHSupplyChainTradeSettlement" 
                        + "/ApplicableCIRHSpecifiedBalanceOut]");
                }

                // 相殺金額
                out.println("CIRHTradeSettlementPayment" 
                    + "/SpecifiedCIRHSupplyChainTradeSettlement[0]"
                    + "/SpecifiedCIRHTradeSettlementMonetarySummation" 
                    + "/ApplicableCIRHSpecifiedBalanceOut/");
                try {
                    out.println("CalculatedAmount[" + cira
                        .getCIRHTradeSettlementPayment()
                        .getSpecifiedCIRHSupplyChainTradeSettlement().get(0)
                        .getSpecifiedCIRHTradeSettlementMonetarySummation()
                        .getApplicableCIRHSpecifiedBalanceOut().get(0)
                        .getCalculatedAmount().getValue() + "]");
                } catch (NullPointerException e) {
                    out.println("[No CalculatedAmount]");
                } catch(IndexOutOfBoundsException e) {
                    out.println("[No SpecifiedCIRHSupplyChainTradeSettlement" 
                        + "/ApplicableCIRHSpecifiedBalanceOut]");
                }

                // 税額（支払全体の合計税額）
                out.println("CIRHTradeSettlementPayment" 
                    + "/SpecifiedCIRHSupplyChainTradeSettlement[0]"
                    + "/ApplicableCITradeTax/");
                try {
                    out.println("CalculatedAmount[" + cira
                        .getCIRHTradeSettlementPayment()
                        .getSpecifiedCIRHSupplyChainTradeSettlement().get(0)
                        .getApplicableCITradeTax().getCalculatedAmount()
                        .getValue() + "]");
                } catch (NullPointerException e) {
                    out.println("[No CalculatedAmount]");
                } catch(IndexOutOfBoundsException e) {
                    out.println("[No SpecifiedCIRHSupplyChainTradeSettlement]");
                }

                // 税区分（支払全体の税区分、全て同じ税区分の場合）
                out.println("CIRHTradeSettlementPayment" 
                    + "/SpecifiedCIRHSupplyChainTradeSettlement[0]"
                    + "/ApplicableCITradeTax/");
                try {
                    out.println("TypeCode[" + cira
                        .getCIRHTradeSettlementPayment()
                        .getSpecifiedCIRHSupplyChainTradeSettlement().get(0)
                        .getApplicableCITradeTax().getTypeCode()
                        .getValue() + "]");
                } catch (NullPointerException e) {
                    out.println("[No TypeCode]");
                } catch(IndexOutOfBoundsException e) {
                    out.println("[No SpecifiedCIRHSupplyChainTradeSettlement]");
                }

                // 税率（支払全体の税率、全て同率の場合）
                out.println("CIRHTradeSettlementPayment" 
                    + "/SpecifiedCIRHSupplyChainTradeSettlement[0]"
                    + "/ApplicableCITradeTax/");
                try {
                    out.println("CalculatedRate[" + cira
                        .getCIRHTradeSettlementPayment()
                        .getSpecifiedCIRHSupplyChainTradeSettlement().get(0)
                        .getApplicableCITradeTax().getCalculatedRate()
                        .getValue() + "]");
                } catch (NullPointerException e) {
                    out.println("[No CalculatedRate]");
                } catch(IndexOutOfBoundsException e) {
                    out.println("[No SpecifiedCIRHSupplyChainTradeSettlement]");
                }

                for(int i = 0; i < cira.getCIRTSupplyChainTradeTransaction().size(); 
                        i++) {
                    out.println("\n--" + i + "--\n");

                    // 行番号
                    out.println("CIRTSupplyChainTradeTransaction[" + i 
                        + "]/AssociatedCIRDocumentLineDocument/");
                    try {
                        out.println("LineID[" + cira
                            .getCIRTSupplyChainTradeTransaction().get(i)
                            .getAssociatedCIRDocumentLineDocument()
                            .getLineID().getValue() + "]");
                    } catch (NullPointerException e) {
                        out.println("[No LineID]");
                    }

                    // 支払内容（請求書毎）
                    out.println("CIRTSupplyChainTradeTransaction[" + i 
                        + "]/AssociatedCIRDocumentLineDocument" 
                        + "/IncludedCINote[0]/");
                    try {
                        out.println("Content[" + cira
                            .getCIRTSupplyChainTradeTransaction().get(i)
                            .getAssociatedCIRDocumentLineDocument()
                            .getIncludedCINote().get(0).getContent().getValue() + "]");
                    } catch (NullPointerException e) {
                        out.println("[No Content]");
                    } catch(IndexOutOfBoundsException e) {
                        out.println("[No IncludedCINote]");
                    }

                    for(int j = 0; 
                            j < cira.getCIRTSupplyChainTradeTransaction().get(i)
                            .getAssociatedCIReferencedDocument().size(); j++) {

                        // 請求書番号（請求書の場合）
                        out.println("CIRTSupplyChainTradeTransaction[" + i 
                            + "]/AssociatedCIReferencedDocument[" + j + "]/");
                        try {
                            out.println("IssuerAssignedID[" + cira
                                .getCIRTSupplyChainTradeTransaction().get(i)
                                .getAssociatedCIReferencedDocument().get(j)
                                .getIssuerAssignedID().getValue() + "]");
                        } catch (NullPointerException e) {
                            out.println("[No IssuerAssignedID]");
                        }

                        // 請求書発行日（請求書の場合）
                        out.println("CIRTSupplyChainTradeTransaction[" + i 
                            + "]/AssociatedCIReferencedDocument[" + j + "]/");
                        try {
                            out.println("IssueDateTime/DateTime[" + cira
                                .getCIRTSupplyChainTradeTransaction().get(i)
                                .getAssociatedCIReferencedDocument().get(j)
                                .getIssueDateTime().getDateTime() + "]");
                        } catch (NullPointerException e) {
                            out.println("[No IssueDateTime/DateTime]");
                        }

                        // 参照文書種別
                        out.println("CIRTSupplyChainTradeTransaction[" + i 
                            + "]/AssociatedCIReferencedDocument[" + j + "]/");
                        try {
                            out.println("ReferenceTypeCode[" + cira
                                .getCIRTSupplyChainTradeTransaction().get(i)
                                .getAssociatedCIReferencedDocument().get(j)
                                .getReferenceTypeCode().getValue() + "]");
                        } catch (NullPointerException e) {
                            out.println("[No ReferenceTypeCode]");
                        }

                        // 契約名（契約書の場合）
                        out.println("CIRTSupplyChainTradeTransaction[" + i 
                            + "]/AssociatedCIReferencedDocument[" + j + "]/");
                        try {
                            out.println("Name[" + cira
                                .getCIRTSupplyChainTradeTransaction().get(i)
                                .getAssociatedCIReferencedDocument().get(j)
                                .getName().getValue() + "]");
                        } catch (NullPointerException e) {
                            out.println("[No Name]");
                        }
                    }

                    // 請求先企業法人コード
                    out.println("CIRTSupplyChainTradeTransaction[" + i 
                        + "]/ApplicableCIRTSupplyChainTradeAgreement" 
                        + "/BuyerCITradeParty/");
                    try {
                        out.println("GlobalID[" + cira
                            .getCIRTSupplyChainTradeTransaction().get(i)
                            .getApplicableCIRTSupplyChainTradeAgreement()
                            .getBuyerCITradeParty().getGlobalID().getValue() + "]");
                    } catch (NullPointerException e) {
                        out.println("[No GlobalID]");
                    }

                    // 請求先企業名
                    out.println("CIRTSupplyChainTradeTransaction[" + i 
                        + "]/ApplicableCIRTSupplyChainTradeSettlement" 
                        + "/BuyerCITradeParty/");
                    try {
                        out.println("Name[" + cira
                            .getCIRTSupplyChainTradeTransaction().get(i)
                            .getApplicableCIRTSupplyChainTradeAgreement()
                            .getBuyerCITradeParty().getName().getValue() + "]");
                    } catch (NullPointerException e) {
                        out.println("[No Name]");
                    }

                    // 締日
                    out.println("CIRTSupplyChainTradeTransaction[" + i 
                        + "]/ApplicableCIRTSupplyChainTradeSettlement");
                    try {
                        out.println("ClosingBookDueDateTime/DateTime[" + cira
                            .getCIRTSupplyChainTradeTransaction().get(i)
                            .getApplicableCIRTSupplyChainTradeSettlement()
                            .getClosingBookDueDateTime().getDateTime() + "]");
                    } catch (NullPointerException e) {
                        out.println("[No ClosingBookDueDateTime/DateTime]");
                    }

                    // 入金予定日
                    out.println("CIRTSupplyChainTradeTransaction[" + i 
                        + "]/ApplicableCIRTSupplyChainTradeSettlement/");
                    try {
                        out.println("ScheduledPaymentDateTime/DateTime[" + cira
                            .getCIRTSupplyChainTradeTransaction().get(i)
                            .getApplicableCIRTSupplyChainTradeSettlement()
                            .getScheduledPaymentDateTime().getDateTime() + "]");
                    } catch (NullPointerException e) {
                        out.println("[No ScheduledPaymentDateTime/DateTime]");
                    }

                    // 請求先連絡担当者
                    out.println("CIRTSupplyChainTradeTransaction[" + i 
                        + "]/ApplicableCIRTSupplyChainTradeSettlement"
                        + "/InvoiceeCITradeParty/DefinedCITradeContact/");
                    try {
                        out.println("PersonName[" + cira
                            .getCIRTSupplyChainTradeTransaction().get(i)
                            .getApplicableCIRTSupplyChainTradeSettlement()
                            .getInvoiceeCITradeParty().getDefinedCITradeContact()
                            .getPersonName().getValue() + "]");
                    } catch (NullPointerException e) {
                        out.println("[No PersonName]");
                    }

                    // 請求先連絡先部門
                    out.println("CIRTSupplyChainTradeTransaction[" + i 
                        + "]/ApplicableCIRTSupplyChainTradeSettlement"
                        + "/InvoiceeCITradeParty/DefinedCITradeContact/");
                    try {
                        out.println("DepartmentName[" + cira
                            .getCIRTSupplyChainTradeTransaction().get(i)
                            .getApplicableCIRTSupplyChainTradeSettlement()
                            .getInvoiceeCITradeParty().getDefinedCITradeContact()
                            .getDepartmentName().getValue() + "]");
                    } catch (NullPointerException e) {
                        out.println("[No DepartmentName]");
                    }

                    // 請求先電話番号
                    out.println("CIRTSupplyChainTradeTransaction[" + i 
                        + "]/ApplicableCIRTSupplyChainTradeSettlement"
                        + "/InvoiceeCITradeParty/DefinedCITradeContact" 
                        + "/TelephoneCIUniversalCommunication/");
                        try {
                        out.println("CompleteNumber[" + cira
                            .getCIRTSupplyChainTradeTransaction().get(i)
                            .getApplicableCIRTSupplyChainTradeSettlement()
                            .getInvoiceeCITradeParty().getDefinedCITradeContact()
                            .getTelephoneCIUniversalCommunication()
                            .getCompleteNumber().getValue() + "]");
                    } catch (NullPointerException e) {
                        out.println("[No CompleteNumber]");
                    }

                    // 支払金額（明細）
                    out.println("CIRTSupplyChainTradeTransaction[" + i 
                        + "]/ApplicableCIRTSupplyChainTradeSettlement"
                        + "/SpecifiedCIRTTradeSettlementMonetarySummation/");
                        try {
                        out.println("PaymentTotalAmount[" + cira
                            .getCIRTSupplyChainTradeTransaction().get(i)
                            .getApplicableCIRTSupplyChainTradeSettlement()
                            .getSpecifiedCIRTTradeSettlementMonetarySummation()
                            .getPaymentTotalAmount().getValue() + "]");
                    } catch (NullPointerException e) {
                        out.println("[No PaymentTotalAmount]");
                    }

                    for(int ln = 0; 
                            ln < cira.getCIRTSupplyChainTradeTransaction().get(i)
                            .getIncludedCIRLSupplyChainTradeLineItem().size(); 
                                ln++) {
                        out.println("\n==" + ln + "==\n");

                        // 納品伝票番号
                        out.println("CIRTSupplyChainTradeTransaction[" + i 
                            + "]/IncludedCIRLSupplyChainTradeLineItem["+ ln +"]/"
                            + "AssociatedCIRDocumentLineDocument/");
                        try {
                            out.println("LineID[" + cira
                                .getCIRTSupplyChainTradeTransaction().get(i)
                                .getIncludedCIRLSupplyChainTradeLineItem()
                                .get(ln)
                                .getAssociatedCIRDocumentLineDocument()
                                .getLineID()
                                .getValue() + "]");
                        } catch (NullPointerException e) {
                            out.println("[No LineID]");
                        }

                        // 発注番号
                        out.println("CIRTSupplyChainTradeTransaction[" + i 
                            + "]/getIncludedCIRLSupplyChainTradeLineItem["
                            + ln +"]"
                            + "/SpecifiedCIRLSupplyChainTradeSettlement[0]" 
                            + "/ReferencedCIRLSupplyChainTradeTransaction"
                            + "/ApplicableCIRLSupplyChainTradeAgreement" 
                            + "/BuyerOrderReferencedCIReferencedDocument/");
                        try {
                            out.println("IssuerAssignedID[" + cira
                                .getCIRTSupplyChainTradeTransaction().get(i)
                                .getIncludedCIRLSupplyChainTradeLineItem()
                                .get(ln)
                                .getSpecifiedCIRLSupplyChainTradeSettlement()
                                .get(0)
                                .getReferencedCIRLSupplyChainTradeTransaction()
                                .getApplicableCIRLSupplyChainTradeAgreement()
                                .getBuyerOrderReferencedCIReferencedDocument()
                                .getIssuerAssignedID().getValue() + "]");
                        } catch (NullPointerException e) {
                            out.println("[No IssuerAssignedID]");
                        } catch(IndexOutOfBoundsException e) {
                            out.println(
                                "[No SpecifiedCIRLSupplyChainTradeSettlement]");
                        }

                        // 受注番号
                        out.println("CIRTSupplyChainTradeTransaction[" + i 
                            + "]/getIncludedCIRLSupplyChainTradeLineItem[" 
                            + ln +"]"
                            + "/SpecifiedCIRLSupplyChainTradeSettlement[0]" 
                            + "/ReferencedCIRLSupplyChainTradeTransaction"
                            + "/ApplicableCIRLSupplyChainTradeAgreement" 
                            + "/SellerOrderReferencedCIReferencedDocument/");
                        try {
                            out.println("IssuerAssignedID[" + cira
                                .getCIRTSupplyChainTradeTransaction().get(i)
                                .getIncludedCIRLSupplyChainTradeLineItem()
                                .get(ln)
                                .getSpecifiedCIRLSupplyChainTradeSettlement()
                                .get(0)
                                .getReferencedCIRLSupplyChainTradeTransaction()
                                .getApplicableCIRLSupplyChainTradeAgreement()
                                .getSellerOrderReferencedCIReferencedDocument()
                                .getIssuerAssignedID().getValue() + "]");
                        } catch (NullPointerException e) {
                            out.println("[No IssuerAssignedID]");
                        } catch(IndexOutOfBoundsException e) {
                            out.println(
                                "[No SpecifiedCIRLSupplyChainTradeSettlement]");
                        }

                        // 単価
                        out.println("CIRTSupplyChainTradeTransaction[" + i 
                            + "]/getIncludedCIRLSupplyChainTradeLineItem["
                            + ln +"]"
                            + "/SpecifiedCIRLSupplyChainTradeSettlement[0]" 
                            + "/ReferencedCIRLSupplyChainTradeTransaction"
                            + "/ApplicableCIRLSupplyChainTradeAgreement" 
                            + "/OrderPriceProductCITradePrice/");
                        try {
                            out.println("ChargeAmount[" + cira
                                .getCIRTSupplyChainTradeTransaction().get(i)
                                .getIncludedCIRLSupplyChainTradeLineItem()
                                .get(ln)
                                .getSpecifiedCIRLSupplyChainTradeSettlement()
                                .get(0)
                                .getReferencedCIRLSupplyChainTradeTransaction()
                                .getApplicableCIRLSupplyChainTradeAgreement()
                                .getOrderPriceProductCITradePrice()
                                .getChargeAmount().getValue() + "]");
                        } catch (NullPointerException e) {
                            out.println("[No ChargeAmount]");
                        } catch(IndexOutOfBoundsException e) {
                            out.println(
                                "[No SpecifiedCIRLSupplyChainTradeSettlement]");
                        }

                        // 数量
                        out.println("CIRTSupplyChainTradeTransaction[" + i 
                            + "]/getIncludedCIRLSupplyChainTradeLineItem["
                            + ln +"]"
                            + "/SpecifiedCIRLSupplyChainTradeSettlement[0]" 
                            + "/ReferencedCIRLSupplyChainTradeTransaction"
                            + "/ApplicableCIRLSupplyChainTradeDelivery/");
                        try {
                            out.println("BilledQuantity[" + cira
                                .getCIRTSupplyChainTradeTransaction().get(i)
                                .getIncludedCIRLSupplyChainTradeLineItem()
                                .get(ln)
                                .getSpecifiedCIRLSupplyChainTradeSettlement()
                                .get(0)
                                .getReferencedCIRLSupplyChainTradeTransaction()
                                .getApplicableCIRLSupplyChainTradeDelivery()
                                .getBilledQuantity().getValue() + "]");
                        } catch (NullPointerException e) {
                            out.println("[No BilledQuantity]");
                        } catch(IndexOutOfBoundsException e) {
                            out.println(
                                "[No SpecifiedCIRLSupplyChainTradeSettlement]");
                        }

                        // 納入番号
                        out.println("CIRTSupplyChainTradeTransaction[" + i 
                            + "]/getIncludedCIRLSupplyChainTradeLineItem["
                            + ln +"]"
                            + "/SpecifiedCIRLSupplyChainTradeSettlement[0]" 
                            + "/ReferencedCIRLSupplyChainTradeTransaction"
                            + "/ApplicableCIRLSupplyChainTradeDelivery" 
                            + "/RequestedDeliveryCISupplyChainEvent/");
                        try {
                            out.println("ID[" + cira
                                .getCIRTSupplyChainTradeTransaction().get(i)
                                .getIncludedCIRLSupplyChainTradeLineItem()
                                .get(ln)
                                .getSpecifiedCIRLSupplyChainTradeSettlement()
                                .get(0)
                                .getReferencedCIRLSupplyChainTradeTransaction()
                                .getApplicableCIRLSupplyChainTradeDelivery()
                                .getRequestedDeliveryCISupplyChainEvent()
                                .getID().getValue() + "]");
                        } catch (NullPointerException e) {
                            out.println("[No ID]");
                        } catch(IndexOutOfBoundsException e) {
                            out.println(
                                "[No SpecifiedCIRLSupplyChainTradeSettlement]");
                        }

                        // 納入日時
                        out.println("CIRTSupplyChainTradeTransaction[" + i 
                            + "]/getIncludedCIRLSupplyChainTradeLineItem[" 
                            + ln +"]"
                            + "/SpecifiedCIRLSupplyChainTradeSettlement[0]" 
                            + "/ReferencedCIRLSupplyChainTradeTransaction"
                            + "/ApplicableCIRLSupplyChainTradeDelivery" 
                            + "/RequestedDeliveryCISupplyChainEvent/");
                        try {
                            out.println("OccurrenceDateTime/DateTime[" + cira
                                .getCIRTSupplyChainTradeTransaction().get(i)
                                .getIncludedCIRLSupplyChainTradeLineItem()
                                .get(ln)
                                .getSpecifiedCIRLSupplyChainTradeSettlement()
                                .get(0)
                                .getReferencedCIRLSupplyChainTradeTransaction()
                                .getApplicableCIRLSupplyChainTradeDelivery()
                                .getRequestedDeliveryCISupplyChainEvent()
                                .getOccurrenceDateTime().getDateTime() + "]");
                        } catch (NullPointerException e) {
                            out.println("[No OccurrenceDateTime/DateTime]");
                        } catch(IndexOutOfBoundsException e) {
                            out.println(
                                "[No SpecifiedCIRLSupplyChainTradeSettlement]");
                        }

                        // 製品コード
                        out.println("CIRTSupplyChainTradeTransaction[" + i 
                            + "]/getIncludedCIRLSupplyChainTradeLineItem[" 
                            + ln +"]"
                            + "/SpecifiedCIRLSupplyChainTradeSettlement[0]" 
                            + "/ReferencedCIRLSupplyChainTradeTransaction"
                            + "/IncludedCITradeProduct/");
                        try {
                            out.println("BuyerAssignedID[" + cira
                                .getCIRTSupplyChainTradeTransaction().get(i)
                                .getIncludedCIRLSupplyChainTradeLineItem()
                                .get(ln)
                                .getSpecifiedCIRLSupplyChainTradeSettlement()
                                .get(0)
                                .getReferencedCIRLSupplyChainTradeTransaction()
                                .getIncludedCITradeProduct()
                                .getBuyerAssignedID().getValue() + "]");
                        } catch (NullPointerException e) {
                            out.println("[No BuyerAssignedID]");
                        } catch(IndexOutOfBoundsException e) {
                            out.println(
                                "[No SpecifiedCIRLSupplyChainTradeSettlement]");
                        }

                        // 製品名
                        out.println("CIRTSupplyChainTradeTransaction[" + i 
                            + "]/getIncludedCIRLSupplyChainTradeLineItem[" 
                            + ln +"]"
                            + "/SpecifiedCIRLSupplyChainTradeSettlement[0]" 
                            + "/ReferencedCIRLSupplyChainTradeTransaction"
                            + "/IncludedCITradeProduct/");
                        try {
                            out.println("Name[" + cira
                                .getCIRTSupplyChainTradeTransaction().get(i)
                                .getIncludedCIRLSupplyChainTradeLineItem()
                                .get(ln)
                                .getSpecifiedCIRLSupplyChainTradeSettlement()
                                .get(0)
                                .getReferencedCIRLSupplyChainTradeTransaction()
                                .getIncludedCITradeProduct()
                                .getName().getValue() + "]");
                        } catch (NullPointerException e) {
                            out.println("[No Name]");
                        } catch(IndexOutOfBoundsException e) {
                            out.println(
                                "[No SpecifiedCIRLSupplyChainTradeSettlement]");
                        }

                        out.println("\n==  ==\n");
                    }
                    out.println("\n--  --\n");
                }

            } else {

                // 不明な名前空間名の処理
                out.println("Unknown XML: namespace[" + ns + "]");
            }
        } catch (Exception e) {
            e.printStackTrace();
        }
    }
}