import java.io.File;
import java.io.StringWriter;
import java.io.PrintStream;

import javax.xml.bind.JAXBContext;
import javax.xml.bind.Marshaller;
import javax.xml.bind.Unmarshaller;
import javax.xml.XMLConstants;
import javax.xml.validation.Schema;
import javax.xml.validation.SchemaFactory;
import javax.xml.datatype.XMLGregorianCalendar;
import javax.xml.datatype.DatatypeFactory;
import un.unece.uncefact.data.standard.crossindustryremittanceadvice._11.*;

import java.math.BigDecimal;
import java.util.Base64;
import java.util.GregorianCalendar;

public class RAOUT {
    public static void main(String[] args) {
        
        CrossIndustryRemittanceAdvice cira = 
            new CrossIndustryRemittanceAdvice();
        CIExchangedDocumentContextType cedc = 
            new CIExchangedDocumentContextType();
        CIDocumentContextParameterType cdcp1 = 
            new CIDocumentContextParameterType();
        IDType id1 = new IDType();
        
        cira.setCIExchangedDocumentContext(cedc);
        cedc.setBusinessProcessSpecifiedCIDocumentContextParameter(cdcp1);
        cdcp1.setID(id1);

        // データ区分
        id1.setValue("01");

        CIDocumentContextParameterType cdcp2 = 
            new CIDocumentContextParameterType();
        cedc.setSubsetSpecifiedCIDocumentContextParameter(cdcp2);

        // 業界区分
        IDType id2 = new IDType();
        cdcp2.setID(id2);
        id2.setValue("JPSFEDI");
        
        CIRExchangedDocumentType ced = new CIRExchangedDocumentType();
        cira.setCIRExchangedDocument(ced);

        // 支払通知番号
        IDType id3 = new IDType();
        ced.setID(id3);
        id3.setValue("AA");

        // 支払通知発行日
        DateTimeType dt1 = new DateTimeType();
        ced.setIssueDateTime(dt1);
        try {
            XMLGregorianCalendar xmlGregCal1 = DatatypeFactory.newInstance()
                .newXMLGregorianCalendar(new GregorianCalendar());
            dt1.setDateTime(xmlGregCal1);

            xmlGregCal1.setYear(2018);
            xmlGregCal1.setMonth(3);
            xmlGregCal1.setDay(2);
            xmlGregCal1.setTimezone(540);
            xmlGregCal1.setTime(20, 11, 10);

            // System.out.println(xmlGregCal);
        } catch (Exception e) {
            e.printStackTrace();
        }

        // 支払内容
        CINoteType cin1 = new CINoteType();
        ced.getIncludedCINote().add(cin1);
        TextType tt1 = new TextType();
        cin1.setContent(tt1);
        tt1.setValue("note");

        CIRHTradeSettlementPaymentType ctsp = 
            new CIRHTradeSettlementPaymentType();
        cira.setCIRHTradeSettlementPayment(ctsp);

        // 支払番号
        IDType id4 = new IDType();
        ctsp.setEndToEndID(id4);
        id4.setValue("1000000000000:2018-03-02:0123456789");

        // 支払日時
        DateTimeType dt2 = new DateTimeType();
        ctsp.setRequestedExecutionDateTime(dt2);
        try {
            XMLGregorianCalendar xmlGregCal2 = DatatypeFactory.newInstance()
                .newXMLGregorianCalendar(new GregorianCalendar());
            dt2.setDateTime(xmlGregCal2);
            
            xmlGregCal2.setYear(2018);
            xmlGregCal2.setMonth(3);
            xmlGregCal2.setDay(2);
            xmlGregCal2.setTimezone(9 * 60);
            xmlGregCal2.setTime(20, 11, 10);

            // System.out.println(xmlGregCa2);
        } catch (Exception e) {
            e.printStackTrace();
        }

        CIRHSupplyChainTradeSettlementType chscts = 
            new CIRHSupplyChainTradeSettlementType();
        ctsp.getSpecifiedCIRHSupplyChainTradeSettlement().add(chscts);

        CITradePartyType ctp1 = new CITradePartyType();
        chscts.setPayeeCITradeParty(ctp1);

        // 受取人企業法人コード
        IDType id5 = new IDType();
        ctp1.setGlobalID(id5);
        id5.setValue("1000000000001");

        // 受取人企業名
        TextType tt2 = new TextType();
        ctp1.setName(tt2);
        tt2.setValue("受取人企業名");
        tt2.setLanguageID("ja");

        // 受取人企業連絡先電話番号
        CITradeContactType ctc1 = new CITradeContactType();
        ctp1.setDefinedCITradeContact(ctc1);
        CIUniversalCommunicationType cuc1 = 
            new CIUniversalCommunicationType();
        ctc1.setTelephoneCIUniversalCommunication(cuc1);
        TextType tt3 = new TextType();
        cuc1.setCompleteNumber(tt3);
        tt3.setValue("06-0000-0000");

        CITradePartyType ctp2 = new CITradePartyType();
        chscts.setPayerCITradeParty(ctp2);

        // 支払人企業法人コード
        IDType id6 = new IDType();
        ctp2.setGlobalID(id6);
        id6.setValue("1000000000000");

        // 支払人企業名
        TextType tt4 = new TextType();
        ctp2.setName(tt4);
        tt4.setValue("支払人企業名");
        tt4.setLanguageID("ja");

        // 支払人企業連絡先電話番号
        CITradeContactType ctc2 = new CITradeContactType();
        ctp2.setDefinedCITradeContact(ctc2);
        CIUniversalCommunicationType cuc2 = 
            new CIUniversalCommunicationType();
        ctc2.setTelephoneCIUniversalCommunication(cuc2);
        TextType tt5 = new TextType();
        cuc2.setCompleteNumber(tt5);
        tt5.setValue("03-0000-0000");

        CIRHTradeSettlementMonetarySummationType chtsms = 
            new CIRHTradeSettlementMonetarySummationType();
        chscts.setSpecifiedCIRHTradeSettlementMonetarySummation(chtsms);
        
        // 支払合計金額
        AmountType at1 = new AmountType();
        chtsms.setPaymentTotalAmount(at1);
        at1.setValue(new BigDecimal(10900));
        at1.setCurrencyID("JPY");

        // 金額相殺項目理由コード
        CIRHSpecifiedBalanceOutType csbo1 = new CIRHSpecifiedBalanceOutType();
        chtsms.getApplicableCIRHSpecifiedBalanceOut().add(csbo1);
        CodeType rc1 = new CodeType();
        csbo1.setReasonCode(rc1);
        rc1.setValue("1");

        // 金額相殺項目理由
        TextType tt6 = new TextType();
        csbo1.setReasonDescription(tt6);
        tt6.setValue("金額相殺理由");
        tt6.setLanguageID("ja");

        // 相殺金額
        AmountType at2 = new AmountType();
        csbo1.setCalculatedAmount(at2);
        at2.setValue(new BigDecimal("100"));
        at2.setCurrencyID("JPY");

        // 税額（支払全体の合計税額）
        CITradeTaxType ctt1 = new CITradeTaxType(); 
        chscts.setApplicableCITradeTax(ctt1);
        AmountType at3 = new AmountType();
        ctt1.setCalculatedAmount(at3);
        at3.setValue(new BigDecimal("900"));

        // 税区分（支払全体の税区分、全て同じ税区分の場合）
        CodeType tc1 = new CodeType();
        ctt1.setTypeCode(tc1);
        tc1.setValue("EXC");

        // 税率（支払全体の税率、全て同率の場合）
        RateType rt1 = new RateType();
        ctt1.setCalculatedRate(rt1);
        rt1.setValue(new BigDecimal("0.09"));

        CIRTSupplyChainTradeTransactionType csctt = 
            new CIRTSupplyChainTradeTransactionType();
        cira.getCIRTSupplyChainTradeTransaction().add(csctt);

        // 行番号
        CIRDocumentLineDocumentType cdld1 = 
            new CIRDocumentLineDocumentType();
        csctt.setAssociatedCIRDocumentLineDocument(cdld1);
        IDType lid = new IDType();
        cdld1.setLineID(lid);
        lid.setValue("L01");

        // 支払内容
        CINoteType cn1 = new CINoteType();
        TextType tt7 = new TextType();

        cdld1.getIncludedCINote().add(cn1);
        cn1.setContent(tt7);
        tt7.setValue("支払内容");
        tt7.setLanguageID("ja");

        CIRTSupplyChainTradeAgreementType cscta = 
            new CIRTSupplyChainTradeAgreementType();
        csctt.setApplicableCIRTSupplyChainTradeAgreement(cscta);
        CITradePartyType ctp3 = new CITradePartyType();
        cscta.setBuyerCITradeParty(ctp3);
        IDType ida = new IDType();

        // 請求先企業法人コード
        ctp3.setGlobalID(ida);
        ida.setValue("1000000000002");

        // 請求先企業名
        TextType tta = new TextType();
        ctp3.setName(tta);
        tta.setValue("請求先企業名");
        tta.setLanguageID("ja");

        CIRTSupplyChainTradeSettlementType ctscts = 
            new CIRTSupplyChainTradeSettlementType();
        csctt.setApplicableCIRTSupplyChainTradeSettlement(ctscts);

        // 締日
        DateTimeType dt4 = new DateTimeType();
        ctscts.setClosingBookDueDateTime(dt4);
        try {
            XMLGregorianCalendar xmlGregCal4 = DatatypeFactory.newInstance()
                .newXMLGregorianCalendar(new GregorianCalendar());
            dt4.setDateTime(xmlGregCal4);
            
            xmlGregCal4.setYear(2018);
            xmlGregCal4.setMonth(2);
            xmlGregCal4.setDay(25);
            xmlGregCal4.setTimezone(9 * 60);
            xmlGregCal4.setTime(0, 0, 0);

            // System.out.println(xmlGregCa2);
        } catch (Exception e) {
            e.printStackTrace();
        }

        // 入金予定日
        DateTimeType dt5 = new DateTimeType();
        ctscts.setScheduledPaymentDateTime(dt5);
        try {
            XMLGregorianCalendar xmlGregCal5 = DatatypeFactory.newInstance()
                .newXMLGregorianCalendar(new GregorianCalendar());
            dt5.setDateTime(xmlGregCal5);
            
            xmlGregCal5.setYear(2018);
            xmlGregCal5.setMonth(3);
            xmlGregCal5.setDay(3);
            xmlGregCal5.setTimezone(9 * 60);
            xmlGregCal5.setTime(0, 0, 0);

            // System.out.println(xmlGregCa2);
        } catch (Exception e) {
            e.printStackTrace();
        }

        CITradePartyType ctp4 = new CITradePartyType();
        ctscts.setInvoiceeCITradeParty(ctp4);
        CITradeContactType ctc3 = new CITradeContactType();
        ctp4.setDefinedCITradeContact(ctc3);

        // 請求先連絡担当者
        TextType ttb = new TextType();
        ctc3.setPersonName(ttb);
        ttb.setValue("請求先連絡担当者");

        // 請求先連絡先部門
        TextType ttc = new TextType();
        ctc3.setDepartmentName(ttb);
        ttc.setValue("請求先連絡部門");

        // 請求先電話番号
        CIUniversalCommunicationType cuc3 = 
            new CIUniversalCommunicationType();
        ctc3.setTelephoneCIUniversalCommunication(cuc3);
        TextType ttd = new TextType();
        cuc3.setCompleteNumber(ttd);
        ttd.setValue("06-0000-0000");

        // 支払金額（明細）
        CIRTTradeSettlementMonetarySummationType cttsms = 
            new CIRTTradeSettlementMonetarySummationType();
        ctscts.setSpecifiedCIRTTradeSettlementMonetarySummation(cttsms);
        AmountType at8 = new AmountType();
        cttsms.setPaymentTotalAmount(at8);
        at8.setValue(new BigDecimal("100000"));

        CIRLSupplyChainTradeLineItemType clsctli = 
            new CIRLSupplyChainTradeLineItemType();
        csctt.getIncludedCIRLSupplyChainTradeLineItem().add(clsctli);

        // 納品伝票番号
        CIRDocumentLineDocumentType cdld2 = 
            new CIRDocumentLineDocumentType(); 
        clsctli.setAssociatedCIRDocumentLineDocument(cdld2);
        IDType idb = new IDType();
        cdld2.setLineID(idb);
        idb.setValue("D000");

        CIRLSupplyChainTradeSettlementType clscts = 
            new CIRLSupplyChainTradeSettlementType();
        clsctli.getSpecifiedCIRLSupplyChainTradeSettlement().add(clscts);

        CIRLSupplyChainTradeTransactionType clsctt = 
            new CIRLSupplyChainTradeTransactionType();
        clscts.setReferencedCIRLSupplyChainTradeTransaction(clsctt);
        CIRLSupplyChainTradeAgreementType clscta = 
            new CIRLSupplyChainTradeAgreementType();
        clsctt.setApplicableCIRLSupplyChainTradeAgreement(clscta);

        // 発注番号
        CIReferencedDocumentType crd3 = new CIReferencedDocumentType();
        clscta.setBuyerOrderReferencedCIReferencedDocument(crd3);
        IDType idc = new IDType();
        crd3.setIssuerAssignedID(idc);
        idc.setValue("200");

        // 単価
        CITradePriceType ctpr1 = new CITradePriceType();
        clscta.setOrderPriceProductCITradePrice(ctpr1);
        AmountType atg = new AmountType();
        ctpr1.setChargeAmount(atg);
        atg.setValue(new BigDecimal("500"));

        // 受注番号
        CIReferencedDocumentType crd4 = new CIReferencedDocumentType();
        clscta.setSellerOrderReferencedCIReferencedDocument(crd4);
        IDType idd = new IDType();
        crd4.setIssuerAssignedID(idd);
        idd.setValue("300");

        CIRLSupplyChainTradeDeliveryType clsctd = 
            new CIRLSupplyChainTradeDeliveryType();
        clsctt.setApplicableCIRLSupplyChainTradeDelivery(clsctd);

        // 数量
        QuantityType qt = new QuantityType();
        clsctd.setBilledQuantity(qt);
        qt.setValue(new BigDecimal("10"));

        CISupplyChainEventType csce = new CISupplyChainEventType();
        clsctd.setRequestedDeliveryCISupplyChainEvent(csce);

        // 納入番号
        IDType ide = new IDType();
        csce.setID(ide);
        ide.setValue("400");

        // 納入日時
        DateTimeType dt6 = new DateTimeType();
        csce.setOccurrenceDateTime(dt6);
        try {
            XMLGregorianCalendar xmlGregCal6 = DatatypeFactory.newInstance()
                .newXMLGregorianCalendar(new GregorianCalendar());
            dt6.setDateTime(xmlGregCal6);
            
            xmlGregCal6.setYear(2018);
            xmlGregCal6.setMonth(2);
            xmlGregCal6.setDay(20);
            xmlGregCal6.setTimezone(9 * 60);
            xmlGregCal6.setTime(0, 0, 0);

            // System.out.println(xmlGregCa2);
        } catch (Exception e) {
            e.printStackTrace();
        }

        CITradeProductType ctpr2 = new CITradeProductType();
        clsctt.setIncludedCITradeProduct(ctpr2);

        // 製品コード
        IDType idf = new IDType();
        ctpr2.setBuyerAssignedID(idf);
        idf.setValue("xxx-yyy-zzz");

        // 製品名
        TextType ttf = new TextType();
        ctpr2.setName(ttf);
        ttf.setValue("製品名");
        ttf.setLanguageID("ja");

        CIReferencedDocumentType crd1 = new CIReferencedDocumentType();
        csctt.getAssociatedCIReferencedDocument().add(crd1);

        // 参照文書種別（契約書）
        CodeType rc2 = new CodeType();
        crd1.setReferenceTypeCode(rc2);
        rc2.setValue("315");

        // 契約名
        TextType tt9 = new TextType();
        crd1.setName(tt9);
        tt9.setValue("契約名");
        tt9.setLanguageID("ja");

        CIReferencedDocumentType crd2 = new CIReferencedDocumentType();
        csctt.getAssociatedCIReferencedDocument().add(crd2);

        // 請求書番号
        IDType id7 = new IDType();
        crd2.setIssuerAssignedID(id7);
        id7.setValue("1000000000001:2018-02-03:101");

        // 請求書発行日
        DateTimeType dt3 = new DateTimeType();
        crd2.setIssueDateTime(dt3);
        try {
            XMLGregorianCalendar xmlGregCal3 = DatatypeFactory.newInstance()
                .newXMLGregorianCalendar(new GregorianCalendar());
            dt3.setDateTime(xmlGregCal3);
            
            xmlGregCal3.setYear(2018);
            xmlGregCal3.setMonth(2);
            xmlGregCal3.setDay(3);
            xmlGregCal3.setTimezone(9 * 60);
            xmlGregCal3.setTime(0, 0, 0);

            // System.out.println(xmlGregCa2);
        } catch (Exception e) {
            e.printStackTrace();
        }

        // 参照文書種別（請求書）
        CodeType rc3 = new CodeType();
        crd2.setReferenceTypeCode(rc3);
        rc3.setValue("380");


        StringWriter stringWriter = new StringWriter();

//        String mimeHeader = "MIME-Version: 1.0\nContent-Type: text/xml\n" 
//                            + "Content-Transfer-Encoding: base64\n";

        try {
            JAXBContext context = JAXBContext
                .newInstance(CrossIndustryRemittanceAdvice.class);
            Marshaller marshaller = context.createMarshaller();
            SchemaFactory sFactory = SchemaFactory
                .newInstance(XMLConstants.W3C_XML_SCHEMA_NS_URI); 
            Schema schema = sFactory.newSchema(
                new File("CrossIndustryRemittanceAdvice.xsd")); 
            marshaller.setSchema(schema);
            marshaller.setEventHandler(new MyValidationEventHandler());

            PrintStream out = new PrintStream(System.out, true, "UTF-8");
            marshaller.setProperty(Marshaller.JAXB_FRAGMENT, false);
            // 出力対象によりXMLヘッダーの扱いが変わることに注意
            // System.out.print("<?xml version=\"1.0\"?>");
            marshaller.setProperty(Marshaller.JAXB_FORMATTED_OUTPUT, true);
            marshaller.marshal(cira, out);

            marshaller.setProperty(Marshaller.JAXB_FRAGMENT, true);
            // 出力対象によりXMLヘッダーの扱いが変わることに注意
            marshaller.setProperty(Marshaller.JAXB_FORMATTED_OUTPUT, false);
            marshaller.marshal(cira, stringWriter);
            String edi = stringWriter.toString();
            out.println(edi);
//
//            String encoded = mimeHeader + Base64.getMimeEncoder()
//                .encodeToString(edi.getBytes());
//            out.println(encoded);

        } catch (Exception e) {
            e.printStackTrace();
        }
        
    }
}